@@ -17,6 +17,11 @@ REQUEST_METHOD_GET = 1
 REQUEST_METHOD_HEAD = 2
 REQUEST_METHOD_POST = 3
 REQUEST_METHOD_PUT = 4
+REQUEST_METHOD_CONNECT = 5
+REQUEST_METHOD_OPTIONS = 6
+REQUEST_METHOD_TRACE = 7
+
+REQUEST_METHOD_UNDEFINED = 8
 
 # getters
 http_request_get_method = lib.http_request_get_method
